from terra_utils.helpers import Choices

TROPP_STATES = Choices(
    ('DRAFT', 100, 'Draft'),
    ('SUBMITTED', 200, 'Submitted'),
    ('ACCEPTED', 300, 'Accepted'),
    ('REFUSED', -1, 'Refused'),
    ('CANCELLED', -100, 'Cancelled'),
    ('MISSING', 0, 'Missing'),
)

TROPP_BASE_LAYER_NAME = 'Base opp layer'

TROPP_PICTURES_STATES_WORKFLOW = False

TROPP_VIEWPOINT_PROPERTIES_SET = {
    'pdf': {
        ('camera', 'Appareil photo'),
    },
    'form': {},
    'filter': {},
}

TROPP_FEATURES_PROPERTIES_FROM_VIEWPOINT = ['commune',]

TROPP_SEARCHABLE_PROPERTIES = {
    'cities': {
        'json_key': 'commune',
        'type': 'single',
    },
    'themes': {
        'json_key': 'themes',
        'type': 'many',
    },
    'road': {
        'json_key': 'voie',
        'type': 'text',
    },
    'site': {
        'json_key': 'site',
        'type': 'text',
    },
}



from django.apps import AppConfig
from django.conf import settings
from django.core.exceptions import ImproperlyConfigured


class TerraOppConfig(AppConfig):
    name = 'terra_opp'

    def ready(self):
        import terra_opp.signals  # noqa
        if 'versatileimagefield' not in settings.INSTALLED_APPS:
            raise ImproperlyConfigured(
                f"'{self.name}' needs 'versatileimagefield' in INSTALLED_APPS"
            )

        from . import settings as defaults
        dj_settings = settings._wrapped.__dict__
        for name in dir(defaults):
            dj_settings.setdefault(name, getattr(defaults, name))



import factory
from django.utils import timezone
from factory.django import FileField

from terra_opp.models import Campaign, Picture, Viewpoint


class CampaignFactory(factory.DjangoModelFactory):
    owner = factory.SubFactory(
        'terra_accounts.tests.factories.TerraUserFactory'
    )
    assignee = factory.SubFactory(
        'terra_accounts.tests.factories.TerraUserFactory'
    )

    class Meta:
        model = Campaign


class ViewpointFactory(factory.DjangoModelFactory):
    point = factory.SubFactory(
        'geostore.tests.factories.FeatureFactory'
    )
    pictures = factory.RelatedFactory(
        'terra_opp.tests.factories.PictureFactory', 'viewpoint'
    )

    class Meta:
        model = Viewpoint


class PictureFactory(factory.DjangoModelFactory):
    owner = factory.SubFactory(
        'terra_accounts.tests.factories.TerraUserFactory'
    )
    date = timezone.datetime(2018, 1, 1, tzinfo=timezone.utc)
    file = FileField(from_path='terra_opp/tests/placeholder.jpg')

    class Meta:
        model = Picture
